\name{hdpmn-package}
\alias{hdpmn-package}
\docType{package}
\title{
  Hierarchical mixture of Dirichlet process of normals (HDPMN)
}
\description{
  Inference for a DP mixture of normal model for related
  random probability measures.
}
\details{
\tabular{ll}{
Package: \tab hdpmn\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2007-04-15\cr
License: \tab GNU \cr
}
The function \code{hdpmn} intializes and carries out Markov chain
Monte Carlo posterior simulation.
Use the function \code{hdpmnPredict} to obtain posterior predictive
draws which can be used to estimate desired summaries.

The model is a DP mixture of normals for related random probability
measures \eqn{H_j}. Each random measure is assumed to arise
as a mixture \eqn{H_j = \epsilon F_0 + (1-\epsilon) F_j} of one common
distribution \eqn{F_0} and a distribution \eqn{F_j} that is specific to
the j-th submodel.

See \cite{Mueller, Quintana and Rosner (2004)} for details of the
model. 
In summary, the implemented model is as follows.
Without loss of generality we assume that each submodel corresponds to
a different study in a set of related studies. 
Let \eqn{\theta_{ij}} denote the i-th observation in the j-th study
(we use \eqn{\theta}, assuming that the model would typically be used
for a random effects distribution).
We assume that \eqn{\theta_{ji}, i=1,\ldots,n_j} are samples from a
random probability measure for the j-th study, which in turn is a mixture of
a measure \eqn{F_0} that is common to all studies, and an idiosyncratic
measure \eqn{F_j} that is specific to the j-th study.
\deqn{
  \theta_{ji} \sim \epsilon F_0 + (1-\epsilon) F_j
  }
The random probability measures \eqn{F_j} in turn are given a
Dirichlet process mixture of normal prior. We assume 
\deqn{
  F_j(\theta) = \int N(\mu,S)  dG_j(\mu),~ j=0,1,\ldots,J
}
with \eqn{G_j \sim DP(G^\star(\eta),\alpha)}.
Here \eqn{\eta} are hyperparameters that index the base measure of the
DP prior. We use a normal base measure and a conjugate hyperprior
\deqn{
  G^\star(\mu) = N(m,B), \mbox{ with } m \sim N(a,A),
  \mbox{ and }
  B^{-1}\sim Wishart(c,(cC)^{-1})
}
The Wisharet prior is parametrized such that \eqn{E(B^{-1}=C^{-1})}.
Let \eqn{\delta_x} denote a point mass at x.
We complete the model with the hyperpriors
\deqn{
  S^{-1} \sim W(q,(qR)^{-1}),~
  p(\epsilon) = \pi_0\delta_0+\pi_1\delta_1+(1-\pi_0-\pi_1)
               Be(a_\epsilon,b_\epsilon) 
}
Regression on observation-specific covariates \eqn{x_{ji}} can be
achieved by including \eqn{x_{ji}} with the outcome \eqn{\theta_{ji}},
and proceeding as if \eqn{(x_{ji},\theta_{ji})} were generated
as \eqn{\theta_{ji}} in the model described above.
See \cite{Mueller et al. (2004, section 3.3)} for details.

}
\author{
Peter Mueller

Maintainer: Peter Mueller <pm@wotan.mdacc.tmc.edu>
}
\references{
   Mueller, P., Quintana, F. and Rosner, G. (2004).
  ``Hierarchical Meta-Analysis over Related Non-parametric Bayesian
  Models.''
  \emph{Journal of the Royal Statistical Society, Series B}, 66,
  735--749.
}
\keyword{ package }

